/*
   Audio File Library

   Copyright 1998, Michael Pruett <michael@68k.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License, or (at your option) any later version.

   This library is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied
   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
   PURPOSE.  See the GNU General Public License for more details.

   You should have received a copy of the GNU General Public
   License along with this program; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
   MA 02111-1307, USA.
 */

/*
   byteorder.c

   This file defines functions which swap bytes.
 */

#include <sys/types.h>
#include "byteorder.h"

UINT16 _byteswapint16 (UINT16 x)
{
  return ((x << 8) | (x >> 8));
}

UINT32 _byteswapint32 (UINT32 x)
{
  UINT8	b1, b2, b3, b4;

  b1 = x>>24;
  b2 = (x>>16) & 0xff;
  b3 = (x>>8) & 0xff;
  b4 = x & 0xff;

  return b1 | (b2 << 8) | (b3 << 16) | (b4 << 24);
}

#ifdef TEST
#  ifdef UINT64
UINT64 _byteswapint64 (UINT64 x)
{
  UINT8 b1, b2, b3, b4, b5, b6, b7, b8;

  b1 = (x>>56) & 0xff;
  b2 = (x>>48) & 0xff;
  b3 = (x>>40) & 0xff;
  b4 = (x>>32) & 0xff;
  b5 = (x>>24) & 0xff;
  b6 = (x>>16) & 0xff;
  b7 = (x>>8) & 0xff;
  b8 = x & 0xff;

  return b1 | (b2 << 8) | (b3 << 16) | (b4 << 24) |
    ((UINT64)b5 << 32) | ((UINT64)b6 << 40) | 
    ((UINT64)b7 << 48) | ((UINT64)b8 << 56);
}
#  endif

int main(void)
{
  UINT16 data16 = 0x1122;
  UINT32 data32 = 0x11223344;
#  ifdef UINT64
  UINT64 data64 = 0x1122334455667788;
#  endif
  printf("%x\n", data16);
  printf("%x\n", _byteswapint16(data16));
  printf("%x\n", data32);
  printf("%x\n", _byteswapint32(data32));
#  ifdef UINT64
  printf("%llx\n", data64);
  printf("%llx\n", _byteswapint64(data64));
#  endif
  return 0;
}
#endif
