/*
	Audio File Library

	Copyright 1998, Michael Pruett <michael@68k.org>

	This library is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as
	published by the Free Software Foundation; either version 2 of
	the License, or (at your option) any later version.

	This library is distributed in the hope that it will be
	useful, but WITHOUT ANY WARRANTY; without even the implied
	warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
	PURPOSE.  See the GNU General Public License for more details.

	You should have received a copy of the GNU General Public
	License along with this program; if not, write to the Free
	Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
	MA 02111-1307, USA.
*/

/*
	byteorder.h

	This file declares functions useful for dealing with byte
	swapping.
*/

#ifndef _BYTEORDER_H
#define _BYTEORDER_H

#include "sized_types.h"

#if defined (__alpha__) || defined (__i386__)
	#define __LITTLEENDIAN__
#elif defined (__mips__) || defined (__ppc__) || defined (__sparc__) \
	|| defined (__hppa__)
	#define __BIGENDIAN__
#endif

#ifdef __LITTLEENDIAN__
#  define HOST_TO_LENDIAN_INT16(x)		((UINT16)(x))
#  define HOST_TO_LENDIAN_INT32(x)		((UINT32)(x))
#  define LENDIAN_TO_HOST_INT16(x)		((UINT16)(x))
#  define LENDIAN_TO_HOST_INT32(x)		((UINT32)(x))
#else
#  define HOST_TO_LENDIAN_INT16(x)		_byteswapint16(x)
#  define HOST_TO_LENDIAN_INT32(x)		_byteswapint32(x)
#  define LENDIAN_TO_HOST_INT16(x)		_byteswapint16(x)
#  define LENDIAN_TO_HOST_INT32(x)		_byteswapint32(x)
#endif

#ifdef __BIGENDIAN__
#  define HOST_TO_BENDIAN_INT16(x)		((UINT16)(x))
#  define HOST_TO_BENDIAN_INT32(x)		((UINT32)(x))
#  define BENDIAN_TO_HOST_INT16(x)		((UINT16)(x))
#  define BENDIAN_TO_HOST_INT32(x)		((UINT32)(x))
#else
#  define HOST_TO_BENDIAN_INT16(x)		_byteswapint16(x)
#  define HOST_TO_BENDIAN_INT32(x)		_byteswapint32(x)
#  define BENDIAN_TO_HOST_INT16(x)		_byteswapint16(x)
#  define BENDIAN_TO_HOST_INT32(x)		_byteswapint32(x)
#endif

UINT16 _byteswapint16 (UINT16 x);
UINT32 _byteswapint32 (UINT32 x);

#endif
